@@ -34,6 +34,7 @@ class GraphqlClient(object):
             "x-authing-app-id": self.options.app_id
             if hasattr(self.options, "app_id")
             else None,
+            'x-authing-lang': self.options.lang if hasattr(self.options, 'lang') else None
         }
         if token:
             headers["authorization"] = "Bearer %s" % token
@@ -42,7 +43,6 @@ class GraphqlClient(object):
 
         result = client.execute(gql(query), variable_values=params)
         if result.errors:
-            print(result.errors)
             errmsg = None
             errcode = None
             for _, err in enumerate(result.errors):
